@@ -1,4 +1,4 @@
-/* $Id: color.c,v 1.9.2.2 2004/11/14 20:50:19 cegger Exp $
+/* $Id: color.c,v 1.20 2005/07/30 11:39:56 cegger Exp $
 ******************************************************************************
 
    Generic color mapping
@@ -28,6 +28,7 @@
 
 #include <string.h>
 #include "color.h"
+#include <ggi/internal/ggi_debug.h>
 
 
 int GGI_color_getpalvec(ggi_visual *vis, int start, int len, ggi_color *colmap)
@@ -40,18 +41,17 @@ int GGI_color_getpalvec(ggi_visual *vis, int start, int len, ggi_color *colmap)
 	return 0;
 }
 
-int GGI_color_setpalvec(ggi_visual *vis, int start, int len, ggi_color *colmap)
+int GGI_color_setpalvec(ggi_visual *vis, int start, int len, const ggi_color *colmap)
 {
-		if (start == GGI_PALETTE_DONTCARE) start = 0;
+	if (start == GGI_PALETTE_DONTCARE) start = 0;
 		
-		if ((colmap == NULL)
-		   || (start < 0)
-		   || (start+len > COLOR_PALPRIV(vis)->numcols)) 
-		{
-			return GGI_ENOSPACE;
-		}
+	if (  (start < 0)
+	   || (start+len > COLOR_PALPRIV(vis)->numcols)) 
+	{
+		return GGI_ENOSPACE;
+	}
 
-		return LIBGGI_PAL(vis)->setPalette(vis, start, len, colmap);
+	return LIBGGI_PAL(vis)->setPalette(vis, start, len, colmap);
 }
 
 /* ---------------------------------------------------------------------- */
@@ -60,20 +60,20 @@ int GGI_color_setpalvec(ggi_visual *vis, int start, int len, ggi_color *colmap)
  * http://www5.informatik.uni-erlangen.de/vampire/stuff/zinsser_vmv03.pdf
  */
 
-ggi_pixel GGI_color_PAL_mapcolor(ggi_visual *vis, ggi_color *col)
+ggi_pixel GGI_color_PAL_mapcolor(ggi_visual *vis, const ggi_color *col)
 {
 	color_palpriv *priv = COLOR_PALPRIV(vis);
 	ggi_color *pal;
 	ggi_pixel closest = 0;
-	uint32 closest_dist;
+	uint32_t closest_dist;
 	int pal_len;
 	int i, r, g, b;
 
-	LIBGGI_ASSERT(LIBGGI_PAL(vis) != NULL, "PAL_mapcolor with LIBGGI_PAL(vis)==NULL");
+	LIB_ASSERT(LIBGGI_PAL(vis) != NULL, "PAL_mapcolor with LIBGGI_PAL(vis)==NULL");
 
 	pal = LIBGGI_PAL(vis)->clut.data;
 
-	LIBGGI_ASSERT(pal != NULL, "PAL_mapcolor with LIBGGI_PAL(vis)->clut.data==NULL");
+	LIB_ASSERT(pal != NULL, "PAL_mapcolor with LIBGGI_PAL(vis)->clut.data==NULL");
 
 	r = col->r;
 	g = col->g;
@@ -85,7 +85,8 @@ ggi_pixel GGI_color_PAL_mapcolor(ggi_visual *vis, ggi_color *col)
 	    priv->prev_col.b == b &&
 	    pal[priv->prev_val].r == r &&
 	    pal[priv->prev_val].g == g &&
-	    pal[priv->prev_val].b == b) {
+	    pal[priv->prev_val].b == b)
+	{
 		return priv->prev_val;
 	}
 
@@ -96,7 +97,7 @@ ggi_pixel GGI_color_PAL_mapcolor(ggi_visual *vis, ggi_color *col)
 #ifndef ABS
 #define ABS(val)	((val) < 0 ? -(val) : val)
 #endif
-		uint32 dist =
+		uint32_t dist =
 			ABS(r - pal[i].r) +
 			ABS(g - pal[i].g) +
 			ABS(b - pal[i].b);
@@ -115,10 +116,10 @@ ggi_pixel GGI_color_PAL_mapcolor(ggi_visual *vis, ggi_color *col)
 		}
 	}
 
-	GGID2(GGIDPRINT_COLOR(
+	DPRINT2_COLOR(
 		"PAL_mapcolor(%p): %04x%04x%04x -> %04x%04x%04x (%d)\n",
 		vis, r, g, b, pal[closest].r, pal[closest].g, pal[closest].b,
-		closest));
+		closest);
 
 	return closest;
 }
@@ -129,56 +130,56 @@ ggi_pixel GGI_color_PAL_mapcolor(ggi_visual *vis, ggi_color *col)
  * optimizations are for older CPUs and likely don't make much difference 
  * on CPUs which implement branch prediction.
  */
-ggi_pixel GGI_color_TRUE16_mapcolor(ggi_visual *vis, ggi_color *col)
+ggi_pixel GGI_color_TRUE16_mapcolor(ggi_visual *vis, const ggi_color *col)
 {
 	ggi_pixel ret;
 	color_truepriv *priv = vis->colorpriv;
 
-	GGID2(GGIDPRINT_COLOR("TRUE16_mapcolor_4to7(%p, "
-			      "{r=0x%x, g=0x%x, b=0x%x}) called\n",
-			      vis, col->r, col->g, col->b));
-
+	DPRINT2_COLOR("TRUE16_mapcolor_4to7(%p, "
+		      "{r=0x%x, g=0x%x, b=0x%x}) called\n",
+		      vis, col->r, col->g, col->b);
+	
 	ret = ((col->r >> priv->red_unmap) & priv->red_mask) |
 	  ((col->g >> priv->green_unmap) & priv->green_mask) |
 	  ((col->b >> priv->blue_unmap) & priv->blue_mask);
 
-	GGID2(GGIDPRINT_COLOR("TRUE16_mapcolor_4to7 returning 0x%x\n", ret));
-
+	DPRINT2_COLOR("TRUE16_mapcolor_4to7 returning 0x%x\n", ret);
+	
 	return ret;
 }
 
-ggi_pixel GGI_color_TRUE_mapcolor(ggi_visual *vis, ggi_color *col)
+ggi_pixel GGI_color_TRUE_mapcolor(ggi_visual *vis, const ggi_color *col)
 {
 	ggi_pixel ret;
 	color_truepriv *priv = vis->colorpriv;
 
-	GGID2(GGIDPRINT_COLOR("TRUE_mapcolor(%p, "
-			      "{r=0x%x, g=0x%x, b=0x%x}) called\n",
-			      vis, col->r, col->g, col->b));
+	DPRINT2_COLOR("TRUE_mapcolor(%p, "
+		      "{r=0x%x, g=0x%x, b=0x%x}) called\n",
+		      vis, col->r, col->g, col->b);
 
 	ret = (SSHIFT(col->r, priv->red_map) & priv->red_mask) |
 	  (SSHIFT(col->g, priv->green_map) & priv->green_mask) |
 	  (SSHIFT(col->b, priv->blue_map) & priv->blue_mask);
 
-	GGID2(GGIDPRINT_COLOR("TRUE_mapcolor returning 0x%x\n", ret));
-
+	DPRINT2_COLOR("TRUE_mapcolor returning 0x%x\n", ret);
+	
 	return ret;
 }
 
-ggi_pixel GGI_color_GREY_mapcolor(ggi_visual *vis, ggi_color *col)
+ggi_pixel GGI_color_GREY_mapcolor(ggi_visual *vis, const ggi_color *col)
 {
 	ggi_pixel ret;
-
-	GGID2(GGIDPRINT_COLOR("GREY_mapcolor(%p, "
-			      "{r=0x%x, g=0x%x, b=0x%x}) called\n",
-			      vis, col->r, col->g, col->b));
-
+	
+	DPRINT2_COLOR("GREY_mapcolor(%p, "
+		      "{r=0x%x, g=0x%x, b=0x%x}) called\n",
+		      vis, col->r, col->g, col->b);
+	
 	/* NB: This formula is not very good... */
 	ret = (col->r*82 + col->g*124 + col->b*50)
 		>> COLOR_GREYPRIV(vis)->shift;
 
-	GGID2(GGIDPRINT_COLOR("GREY_mapcolor returning 0x%x\n", ret));
-
+	DPRINT2_COLOR("GREY_mapcolor returning 0x%x\n", ret);
+	
 	return ret;
 }
 
@@ -188,9 +189,9 @@ ggi_pixel GGI_color_GREY_mapcolor(ggi_visual *vis, ggi_color *col)
 
 int GGI_color_PAL_unmappixel(ggi_visual *vis, ggi_pixel pixel, ggi_color *col)
 {
-	LIBGGI_ASSERT(LIBGGI_PAL(vis) != NULL, 
+	LIB_ASSERT(LIBGGI_PAL(vis) != NULL, 
 			"PAL_unmappixel with LIBGGI_PAL(vis)==NULL");
-	LIBGGI_ASSERT(LIBGGI_PAL(vis)->clut.data != NULL, 
+	LIB_ASSERT(LIBGGI_PAL(vis)->clut.data != NULL, 
 			"PAL_unmappixel with LIBGGI_PAL(vis)->clut.data==NULL");
 	
 	if (pixel >= (unsigned)COLOR_PALPRIV(vis)->numcols)
