@@ -1,4 +1,4 @@
-/* $Id: visual.c,v 1.3 2004/02/23 14:24:42 pekberg Exp $
+/* $Id: visual.c,v 1.5 2005/07/30 11:39:58 cegger Exp $
 ******************************************************************************
 
   InterLeaved BitMap (planar) graphics.
@@ -29,7 +29,7 @@
 
 
 static int GGIopen(ggi_visual *vis, struct ggi_dlhandle *dlh,
-		   const char *args, void *argptr, uint32 *dlret)
+		   const char *args, void *argptr, uint32_t *dlret)
 {
 	/* Frame handling
 	 */
@@ -59,7 +59,7 @@ int GGIdl_ilbm(int func, void **funcptr)
 {
 	switch (func) {
 	case GGIFUNC_open:
-		*funcptr = GGIopen;
+		*funcptr = (void *)GGIopen;
 		return 0;
 	case GGIFUNC_exit:
 	case GGIFUNC_close:
