@@ -1,4 +1,4 @@
-/* $Id: gtext.c,v 1.8 2004/08/17 08:39:32 cegger Exp $
+/* $Id: gtext.c,v 1.10 2005/07/30 10:58:22 cegger Exp $
 ******************************************************************************
 
    Graphics library for GGI. Textfunctions for X.
@@ -46,7 +46,7 @@ int GGI_X_getcharsize_font(ggi_visual *vis, int *width, int *height)
 int GGI_X_putc_slave_draw(ggi_visual *vis, int x, int y, char c)
 {
 	ggi_x_priv *priv;
-	uint8  *datafg, *databg, *ptr;
+	uint8_t  *datafg, *databg, *ptr;
 	ggi_color *colors, gccolor;
 	int i, w, h;
 
@@ -84,7 +84,7 @@ int GGI_X_putc_slave_draw(ggi_visual *vis, int x, int y, char c)
        		memcpy(colors + i, &gccolor, sizeof(ggi_color));
 	priv->slave->opcolor->packcolors(priv->slave, databg, colors, w * h);
 	free(colors);
-	ptr = (uint8 *)(priv->fontimg->data) + 
+	ptr = (uint8_t *)(priv->fontimg->data) + 
 	  (w * (unsigned int)(unsigned char)c + priv->fontimg->xoffset) * 
 	  priv->fontimg->bits_per_pixel / 8;
 	for (i = 0; i < h; i++) {
@@ -106,7 +106,7 @@ int GGI_X_putc_slave_draw(ggi_visual *vis, int x, int y, char c)
 
 	y = GGI_X_WRITE_Y;
 
-	ggLock(priv->xliblock);
+	GGI_X_LOCK_XLIB(vis);
 
 	XSetForeground(priv->disp, priv->gc, LIBGGI_GC_BGCOLOR(vis));
 	XFillRectangle(priv->disp, priv->drawable, priv->gc, x, y,
@@ -117,7 +117,7 @@ int GGI_X_putc_slave_draw(ggi_visual *vis, int x, int y, char c)
 
 	GGI_X_MAYBE_SYNC(vis);
 
-	ggUnlock(priv->xliblock);
+	GGI_X_UNLOCK_XLIB(vis);
 
 	return 0;
 }
@@ -130,7 +130,7 @@ int GGI_X_putc_draw(ggi_visual *vis, int x, int y, char c)
 
 	y = GGI_X_WRITE_Y;
 
-	ggLock(priv->xliblock);
+	GGI_X_LOCK_XLIB(vis);
 
 	XSetForeground(priv->disp, priv->gc, LIBGGI_GC_BGCOLOR(vis));
 	XFillRectangle(priv->disp, priv->drawable, priv->gc,
@@ -144,7 +144,7 @@ int GGI_X_putc_draw(ggi_visual *vis, int x, int y, char c)
 	
 	GGI_X_MAYBE_SYNC(vis);
 
-	ggUnlock(priv->xliblock);
+	GGI_X_UNLOCK_XLIB(vis);
 
 	return 0;
 }
