@@ -1,4 +1,4 @@
-/* $Id: ddinit.c,v 1.40 2004/09/24 12:30:11 pekberg Exp $
+/* $Id$
 *****************************************************************************
 
    LibGGI DirectX target - Internal functions
@@ -28,8 +28,14 @@
 
 #include "config.h"
 #include <ggi/internal/ggi-dl.h>
+#include <ggi/internal/ggi_debug.h>
 #include "ddinit.h"
+#include "cursor.inc"
+#ifdef __CYGWIN__
+#include <pthread.h>
+#else
 #include <process.h>
+#endif
 
 static void DDCreateClass(directx_priv *priv);
 static int DDCreateWindow(ggi_visual *vis);
@@ -38,7 +44,7 @@ static int DDCreateSurface(directx_priv *priv, ggi_mode *mode);
 static void DDDestroySurface(directx_priv *priv);
 static void DDChangeWindow(directx_priv *priv, DWORD width, DWORD height);
 
-long FAR PASCAL
+static long FAR PASCAL
 WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam);
 
 int
@@ -68,13 +74,15 @@ DDInit(ggi_visual *vis)
 void
 DDShutdown(directx_priv *priv)
 {
+	void *res;
+
 	/* kill the timer callback */
 	if (priv->timer_id)
 		KillTimer(priv->hWnd, priv->timer_id);
 
 	/* destroy the window and the surface */
 	if (priv->hWnd && !priv->hParent) {
-		GGIDPRINT("display-directx: End session\n");
+		DPRINT("End session\n");
 		PostThreadMessage(priv->nThreadID, WM_DDEND, 0, 0);
 	}
 	DDDestroySurface(priv);
@@ -88,16 +96,24 @@ DDShutdown(directx_priv *priv)
 		priv->lpdd = NULL;
 	}
 
+#ifdef __CYGWIN__
+	DPRINT("Join helper thread\n");
+	if (priv->hThread &&
+	    pthread_join((pthread_t)priv->hThread, &res))
+	{
+		DPRINT("Failed to join helper thread\n");
+	}
+#else
 	/* stop the event loop */
 	if (priv->hThread &&
 	    WaitForSingleObject(priv->hThread, 2000) != WAIT_OBJECT_0) {
 		/* asta la vista, baby */
-		GGIDPRINT("display-directx: "
-			  "Terminating helper thread harshly\n");
+		DPRINT("Terminating helper thread harshly\n");
 		TerminateThread(priv->hThread, 0);
 	}
 	if (priv->hThread)
 		CloseHandle(priv->hThread);
+#endif
 
 	/* Get rid of the window class if we registered it */
 	if (priv->wndclass)
@@ -133,9 +149,8 @@ static BOOL CALLBACK
 ModeCallback(LPDDSURFACEDESC sd, LPVOID ctx)
 {
 	matchmode *mm = (matchmode *)ctx;
-	directx_priv *priv = GGIDIRECTX_PRIV(mm->vis);
 	ggi_mode *mode = mm->mode;
-	char *msg;
+	const char *msg;
 	int ndx, bdx, ndy, bdy;
 
 	if (GT_DEPTH(mode->graphtype) != GT_AUTO) {
@@ -145,7 +160,7 @@ ModeCallback(LPDDSURFACEDESC sd, LPVOID ctx)
 			if (sd->ddpfPixelFormat.dwRGBBitCount > mm->bits)
 				goto accept;
 			if (sd->ddpfPixelFormat.dwRGBBitCount < mm->bits) {
-				msg = "directx: rej mode (%i,%i) "
+				msg = "rej mode (%i,%i) "
 					"poorer depth %i\n";
 				goto next;
 			}
@@ -158,7 +173,7 @@ ModeCallback(LPDDSURFACEDESC sd, LPVOID ctx)
 			if (sd->ddpfPixelFormat.dwRGBBitCount < mm->bits)
 				goto accept;
 			if (sd->ddpfPixelFormat.dwRGBBitCount > mm->bits) {
-				msg = "directx: rej mode (%i,%i) "
+				msg = "rej mode (%i,%i) "
 					"poorer depth %i\n";
 				goto next;
 			}
@@ -172,7 +187,7 @@ ModeCallback(LPDDSURFACEDESC sd, LPVOID ctx)
 			goto accept;
 		if (mm->bestx * mm->besty < (int)(sd->dwWidth * sd->dwHeight))
 			goto accept;
-		msg = "directx: rej smaller mode (%i,%i) depth %i\n";
+		msg = "rej smaller mode (%i,%i) depth %i\n";
 		goto next;
 	}
 
@@ -188,7 +203,7 @@ ModeCallback(LPDDSURFACEDESC sd, LPVOID ctx)
 	if (ndx >= 0 && ndy >= 0 && (bdx < 0 || bdy < 0))
 		goto accept;
 	if ((ndx < 0 || ndy < 0) && bdx >= 0 && bdy >= 0) {
-		msg = "directx: rej bad mode (%i,%i) depth %i\n";
+		msg = "rej bad mode (%i,%i) depth %i\n";
 		goto next;
 	}
 	if (ndx*ndx + ndy*ndy < bdx*bdx + bdy*bdy)
@@ -196,19 +211,19 @@ ModeCallback(LPDDSURFACEDESC sd, LPVOID ctx)
 	if (ndx*ndx + ndy*ndy == bdx*bdx + bdy*bdy) {
 		if (sd->ddpfPixelFormat.dwRGBBitCount >= mm->bits)
 			goto accept;
-		msg = "directx: rej mode (%i,%i) poorer depth %i\n";
+		msg = "rej mode (%i,%i) poorer depth %i\n";
 		goto next;
 	}
-	msg = "directx: rej worse mode (%i,%i) depth %i\n";
+	msg = "rej worse mode (%i,%i) depth %i\n";
 	goto next;
 
 accept:
-	msg = "directx: best mode so far (%i,%i) depth %i\n";
+	msg = "best mode so far (%i,%i) depth %i\n";
 	mm->bestx = sd->dwWidth;
 	mm->besty = sd->dwHeight;
 	mm->bits  = sd->ddpfPixelFormat.dwRGBBitCount;
 next:
-	GGIDPRINT_MODE(msg, sd->dwWidth, sd->dwHeight,
+	DPRINT_MODE(msg, sd->dwWidth, sd->dwHeight,
 		sd->ddpfPixelFormat.dwRGBBitCount);
 	return DDENUMRET_OK;
 }
@@ -339,180 +354,61 @@ DDRedrawAll(ggi_visual *vis)
 
 /* internal routines ********************************************************/
 
-/* cursors */
+static void
+DDNotifyResize(ggi_visual *vis, int xsize, int ysize)
+{
+	ggi_event ev;
+	ggi_cmddata_switchrequest *swreq;
+	directx_priv *priv = GGIDIRECTX_PRIV(vis);
 
-static BYTE ANDmaskInvCursor[] = {
-	0xff, 0xff, 0xff, 0xff,	// line 1
-	0xff, 0xff, 0xff, 0xff,	// line 2
-	0xff, 0xff, 0xff, 0xff,	// line 3
-	0xff, 0xff, 0xff, 0xff,	// line 4
+	DPRINT_DRAW("DDNotifyResize(%p, %dx%d) called\n",
+		       vis, xsize, ysize);
 
-	0xff, 0xff, 0xff, 0xff,	// line 5
-	0xff, 0xff, 0xff, 0xff,	// line 6
-	0xff, 0xff, 0xff, 0xff,	// line 7
-	0xff, 0xff, 0xff, 0xff,	// line 8
+	/* This is racy, what if window is resized and
+	 * resized back before the app gets to react
+	 * to the first resize notification?
+	 */
+	if (!LIBGGI_X(vis) || !LIBGGI_Y(vis)) {
+		DPRINT_DRAW("DDNotifyResize: No old size, ignore\n");
+		return;
+	}
+	if ((LIBGGI_X(vis) == xsize) &&
+	    (LIBGGI_Y(vis) == ysize))
+	{
+		DPRINT_DRAW("DDNotifyResize: Same size, ignore\n");
+		return;
+	}
+	DPRINT_DRAW("DDNotifyResize: Old size %ux%u\n",
+		LIBGGI_X(vis), LIBGGI_Y(vis));
 
-	0xff, 0xff, 0xff, 0xff,	// line 9
-	0xff, 0xff, 0xff, 0xff,	// line 10
-	0xff, 0xff, 0xff, 0xff,	// line 11
-	0xff, 0xff, 0xff, 0xff,	// line 12
+	_giiEventBlank(&ev, sizeof(gii_cmd_event));
 
-	0xff, 0xff, 0xff, 0xff,	// line 13
-	0xff, 0xff, 0xff, 0xff,	// line 14
-	0xff, 0xff, 0xff, 0xff,	// line 15
-	0xff, 0xff, 0xff, 0xff,	// line 16
+	ev.any.size=	sizeof(gii_cmd_nodata_event) +
+			sizeof(ggi_cmddata_switchrequest);
+	ev.any.type=	evCommand;
+	ev.cmd.code=	GGICMD_REQUEST_SWITCH;
 
-	0xff, 0xff, 0xff, 0xff,	// line 17
-	0xff, 0xff, 0xff, 0xff,	// line 18
-	0xff, 0xff, 0xff, 0xff,	// line 19
-	0xff, 0xff, 0xff, 0xff,	// line 20
+	swreq = (ggi_cmddata_switchrequest *) ev.cmd.data;
+	swreq->request = GGI_REQSW_MODE;
+	swreq->mode = *LIBGGI_MODE(vis);
 
-	0xff, 0xff, 0xff, 0xff,	// line 21
-	0xff, 0xff, 0xff, 0xff,	// line 22
-	0xff, 0xff, 0xff, 0xff,	// line 23
-	0xff, 0xff, 0xff, 0xff,	// line 24
+	swreq->mode.visible.x = xsize;
+	swreq->mode.visible.y = ysize;
+	if (swreq->mode.virt.x < xsize)
+		swreq->mode.virt.x = xsize;
+	if (swreq->mode.virt.y < ysize)
+		swreq->mode.virt.y = ysize;
+	swreq->mode.size.x = GGI_AUTO;
+	swreq->mode.size.y = GGI_AUTO;
 
-	0xff, 0xff, 0xff, 0xff,	// line 25
-	0xff, 0xff, 0xff, 0xff,	// line 26
-	0xff, 0xff, 0xff, 0xff,	// line 27
-	0xff, 0xff, 0xff, 0xff,	// line 28
-
-	0xff, 0xff, 0xff, 0xff,	// line 29
-	0xff, 0xff, 0xff, 0xff,	// line 30
-	0xff, 0xff, 0xff, 0xff,	// line 31
-	0xff, 0xff, 0xff, 0xff	// line 32
-};
-
-static BYTE XORmaskInvCursor[] = {
-	0x00, 0x00, 0x00, 0x00,	// line 1
-	0x00, 0x00, 0x00, 0x00,	// line 2
-	0x00, 0x00, 0x00, 0x00,	// line 3
-	0x00, 0x00, 0x00, 0x00,	// line 4
-
-	0x00, 0x00, 0x00, 0x00,	// line 5
-	0x00, 0x00, 0x00, 0x00,	// line 6
-	0x00, 0x00, 0x00, 0x00,	// line 7
-	0x00, 0x00, 0x00, 0x00,	// line 8
-
-	0x00, 0x00, 0x00, 0x00,	// line 9
-	0x00, 0x00, 0x00, 0x00,	// line 10
-	0x00, 0x00, 0x00, 0x00,	// line 11
-	0x00, 0x00, 0x00, 0x00,	// line 12
-
-	0x00, 0x00, 0x00, 0x00,	// line 13
-	0x00, 0x00, 0x00, 0x00,	// line 14
-	0x00, 0x00, 0x00, 0x00,	// line 15
-	0x00, 0x00, 0x00, 0x00,	// line 16
-
-	0x00, 0x00, 0x00, 0x00,	// line 17
-	0x00, 0x00, 0x00, 0x00,	// line 18
-	0x00, 0x00, 0x00, 0x00,	// line 19
-	0x00, 0x00, 0x00, 0x00,	// line 20
-
-	0x00, 0x00, 0x00, 0x00,	// line 21
-	0x00, 0x00, 0x00, 0x00,	// line 22
-	0x00, 0x00, 0x00, 0x00,	// line 23
-	0x00, 0x00, 0x00, 0x00,	// line 24
-
-	0x00, 0x00, 0x00, 0x00,	// line 25
-	0x00, 0x00, 0x00, 0x00,	// line 26
-	0x00, 0x00, 0x00, 0x00,	// line 27
-	0x00, 0x00, 0x00, 0x00,	// line 28
-
-	0x00, 0x00, 0x00, 0x00,	// line 29
-	0x00, 0x00, 0x00, 0x00,	// line 30
-	0x00, 0x00, 0x00, 0x00,	// line 31
-	0x00, 0x00, 0x00, 0x00	// line 32
-};
-
-static BYTE ANDmaskDotCursor[] = {
-	0xff, 0xff, 0xff, 0xff,	// line 1
-	0xff, 0xff, 0xff, 0xff,	// line 2
-	0xff, 0xff, 0xff, 0xff,	// line 3
-	0xff, 0xff, 0xff, 0xff,	// line 4
-
-	0xff, 0xff, 0xff, 0xff,	// line 5
-	0xff, 0xff, 0xff, 0xff,	// line 6
-	0xff, 0xff, 0xff, 0xff,	// line 7
-	0xff, 0xff, 0xff, 0xff,	// line 8
-
-	0xff, 0xff, 0xff, 0xff,	// line 9
-	0xff, 0xff, 0xff, 0xff,	// line 10
-	0xff, 0xff, 0xff, 0xff,	// line 11
-	0xff, 0xff, 0xff, 0xff,	// line 12
-
-	0xff, 0xff, 0xff, 0xff,	// line 13
-	0xff, 0xff, 0xff, 0xff,	// line 14
-	0xff, 0xff, 0xff, 0xff,	// line 15
-	0xff, 0xfe, 0xff, 0xff,	// line 16
-
-	0xff, 0xfd, 0x7f, 0xff,	// line 17
-	0xff, 0xfe, 0xff, 0xff,	// line 18
-	0xff, 0xff, 0xff, 0xff,	// line 19
-	0xff, 0xff, 0xff, 0xff,	// line 20
-
-	0xff, 0xff, 0xff, 0xff,	// line 21
-	0xff, 0xff, 0xff, 0xff,	// line 22
-	0xff, 0xff, 0xff, 0xff,	// line 23
-	0xff, 0xff, 0xff, 0xff,	// line 24
-
-	0xff, 0xff, 0xff, 0xff,	// line 25
-	0xff, 0xff, 0xff, 0xff,	// line 26
-	0xff, 0xff, 0xff, 0xff,	// line 27
-	0xff, 0xff, 0xff, 0xff,	// line 28
-
-	0xff, 0xff, 0xff, 0xff,	// line 29
-	0xff, 0xff, 0xff, 0xff,	// line 30
-	0xff, 0xff, 0xff, 0xff,	// line 31
-	0xff, 0xff, 0xff, 0xff	// line 32
-};
-
-static BYTE XORmaskDotCursor[] = {
-	0x00, 0x00, 0x00, 0x00,	// line 1
-	0x00, 0x00, 0x00, 0x00,	// line 2
-	0x00, 0x00, 0x00, 0x00,	// line 3
-	0x00, 0x00, 0x00, 0x00,	// line 4
-
-	0x00, 0x00, 0x00, 0x00,	// line 5
-	0x00, 0x00, 0x00, 0x00,	// line 6
-	0x00, 0x00, 0x00, 0x00,	// line 7
-	0x00, 0x00, 0x00, 0x00,	// line 8
-
-	0x00, 0x00, 0x00, 0x00,	// line 9
-	0x00, 0x00, 0x00, 0x00,	// line 10
-	0x00, 0x00, 0x00, 0x00,	// line 11
-	0x00, 0x00, 0x00, 0x00,	// line 12
-
-	0x00, 0x00, 0x00, 0x00,	// line 13
-	0x00, 0x00, 0x00, 0x00,	// line 14
-	0x00, 0x00, 0x00, 0x00,	// line 15
-	0x00, 0x01, 0x00, 0x00,	// line 16
-
-	0x00, 0x02, 0x80, 0x00,	// line 17
-	0x00, 0x01, 0x00, 0x00,	// line 18
-	0x00, 0x00, 0x00, 0x00,	// line 19
-	0x00, 0x00, 0x00, 0x00,	// line 20
-
-	0x00, 0x00, 0x00, 0x00,	// line 21
-	0x00, 0x00, 0x00, 0x00,	// line 22
-	0x00, 0x00, 0x00, 0x00,	// line 23
-	0x00, 0x00, 0x00, 0x00,	// line 24
-
-	0x00, 0x00, 0x00, 0x00,	// line 25
-	0x00, 0x00, 0x00, 0x00,	// line 26
-	0x00, 0x00, 0x00, 0x00,	// line 27
-	0x00, 0x00, 0x00, 0x00,	// line 28
-
-	0x00, 0x00, 0x00, 0x00,	// line 29
-	0x00, 0x00, 0x00, 0x00,	// line 30
-	0x00, 0x00, 0x00, 0x00,	// line 31
-	0x00, 0x00, 0x00, 0x00	// line 32
-};
+	_giiSafeAdd(priv->inp, &ev);
+}
 
 
 static void
-DDSizing(directx_priv *priv, WPARAM wParam, LPRECT rect)
+DDSizing(ggi_visual *vis, WPARAM wParam, LPRECT rect)
 {
+	directx_priv *priv = GGIDIRECTX_PRIV(vis);
 	int xsize, ysize;
 	RECT diff, test1, test2;
 	DWORD ws_style = WS_OVERLAPPEDWINDOW & ~WS_MAXIMIZEBOX;
@@ -538,6 +434,7 @@ DDSizing(directx_priv *priv, WPARAM wParam, LPRECT rect)
 	/* Calculate new size, with regard to max/min/step */
 	xsize = rect->right  - rect->left;
 	ysize = rect->bottom - rect->top;
+	DPRINT_DRAW("Wants resize to %ux%u\n", xsize, ysize);
 	if (xsize < priv->xmin)
 		xsize = priv->xmin;
 	if (xsize > priv->xmax)
@@ -580,11 +477,14 @@ DDSizing(directx_priv *priv, WPARAM wParam, LPRECT rect)
 	rect->bottom -= diff.bottom;
 	rect->left   -= diff.left;
 	rect->right  -= diff.right;
+
+	DPRINT_DRAW("Gets resize to %ux%u\n", xsize, ysize);
+	DDNotifyResize(vis, xsize, ysize);
 }
 
 /* GGI window procedure */
 
-long FAR PASCAL
+static long FAR PASCAL
 WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 {
 	LPCREATESTRUCT lpcs;
@@ -600,70 +500,57 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 
 	switch (message) {
 
-	case WM_DDREDRAW:
-		if (!TryEnterCriticalSection(&priv->cs)) {
-			/* spin */
-			PostMessage(hWnd, message, wParam, lParam);
-			return 0;
-		}
-		DDRedrawAll(vis);
-		EnterCriticalSection(&priv->spincs);
-		priv->redraw = 1;
-		LeaveCriticalSection(&priv->spincs);
-		LeaveCriticalSection(&priv->cs);
-		return 0;
-
 	case WM_DDSETPALETTE:
 		{
 			int setpalette;
-			EnterCriticalSection(&priv->spincs);
+			GGI_directx_Lock(priv->spincs);
 			setpalette = priv->setpalette;
-			LeaveCriticalSection(&priv->spincs);
+			GGI_directx_Unlock(priv->spincs);
 			if(setpalette)
 				/* setpalette canceled */
 				return 0;
 		}
-		if(!TryEnterCriticalSection(&priv->cs)) {
+		if(GGI_directx_TryLock(priv->cs)) {
 			/* spin */
 			PostMessage(hWnd, message, wParam, lParam);
 			return 0;
 		}
 		if(priv->lpddp)
 			DDChangePalette(vis);
-		EnterCriticalSection(&priv->spincs);
+		GGI_directx_Lock(priv->spincs);
 		priv->setpalette = 1;
-		LeaveCriticalSection(&priv->spincs);
-		LeaveCriticalSection(&priv->cs);
+		GGI_directx_Unlock(priv->spincs);
+		GGI_directx_Unlock(priv->cs);
 		return 0;
 
 	case WM_TIMER:
 		if (wParam != 1)
 			break;
-		if (!TryEnterCriticalSection(&priv->cs)) {
+		if (GGI_directx_TryLock(priv->cs)) {
 			int redraw = 0;
-			EnterCriticalSection(&priv->spincs);
+			GGI_directx_Lock(priv->spincs);
 			redraw = priv->redraw;
 			priv->redraw = 0;
-			LeaveCriticalSection(&priv->spincs);
+			GGI_directx_Unlock(priv->spincs);
 			if (redraw)
 				/* spin */
 				PostMessage(hWnd, WM_USER, wParam, lParam);
 			return 0;
 		}
 		DDRedrawAll(vis);
-		LeaveCriticalSection(&priv->cs);
+		GGI_directx_Unlock(priv->cs);
 		return 0;
 
 	case WM_PAINT:
-		if (!TryEnterCriticalSection(&priv->cs)) {
+		if (GGI_directx_TryLock(priv->cs)) {
 			int redraw = 0;
-			EnterCriticalSection(&priv->spincs);
+			GGI_directx_Lock(priv->spincs);
 			redraw = priv->redraw;
 			priv->redraw = 0;
-			LeaveCriticalSection(&priv->spincs);
+			GGI_directx_Unlock(priv->spincs);
 			if (redraw)
 				/* spin */
-				PostMessage(hWnd, WM_DDREDRAW, wParam, lParam);
+				InvalidateRect(hWnd, NULL, 0);
 			return 0;
 		}
 		if (GetUpdateRect(hWnd, &dirty, FALSE)) {
@@ -697,26 +584,43 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 				ps.rcPaint.bottom - ps.rcPaint.top);
 			EndPaint(hWnd, &ps);
 		}
-		LeaveCriticalSection(&priv->cs);
+		GGI_directx_Unlock(priv->cs);
 		return 0;
 
 	case WM_SIZING:
-		EnterCriticalSection(&priv->sizingcs);
+		GGI_directx_Lock(priv->sizingcs);
 		if (priv->xstep < 0) {
-			LeaveCriticalSection(&priv->sizingcs);
+			GGI_directx_Unlock(priv->sizingcs);
 			break;
 		}
-		DDSizing(priv, wParam, (LPRECT) lParam);
-		LeaveCriticalSection(&priv->sizingcs);
+		DDSizing(vis, wParam, (LPRECT) lParam);
+		GGI_directx_Unlock(priv->sizingcs);
 		return TRUE;
 
+	case WM_SIZE:
+		switch(wParam) {
+		case SIZE_MAXIMIZED:
+		case SIZE_RESTORED:
+			break;
+		default:
+			return 0;
+		}
+		GGI_directx_Lock(priv->sizingcs);
+		if (priv->xstep < 0) {
+			GGI_directx_Unlock(priv->sizingcs);
+			break;
+		}
+		DDNotifyResize(vis, LOWORD(lParam), HIWORD(lParam));
+		GGI_directx_Unlock(priv->sizingcs);
+		return 0;
+
 	case WM_QUERYNEWPALETTE:
-		if(!TryEnterCriticalSection(&priv->cs)) {
+		if(GGI_directx_TryLock(priv->cs)) {
 			int setpalette = 0;
-			EnterCriticalSection(&priv->spincs);
+			GGI_directx_Lock(priv->spincs);
 			setpalette = priv->setpalette;
 			priv->redraw = 0;
-			LeaveCriticalSection(&priv->spincs);
+			GGI_directx_Unlock(priv->spincs);
 			if(setpalette)
 				/* spin */
 				PostMessage(hWnd, WM_DDSETPALETTE,
@@ -724,11 +628,11 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			return 0;
 		}
 		if(!priv->lpddp) {
-			LeaveCriticalSection(&priv->cs);
+			GGI_directx_Unlock(priv->cs);
 			break;
 		}
 		DDChangePalette(vis);
-		LeaveCriticalSection(&priv->cs);
+		GGI_directx_Unlock(priv->cs);
 		return TRUE;
 
 	case WM_CREATE:
@@ -746,7 +650,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 		if (priv->inp) {
 			gii_event ev;
 
-			GGIDPRINT("display-directx: tell inputlib about "
+			DPRINT("tell inputlib about "
 				  "new system parameters\n");
 
 			ev.cmd.size = sizeof(gii_cmd_event);
@@ -870,6 +774,8 @@ DDEventLoop(void *lpParm)
 	ggi_visual *vis = (ggi_visual *) lpParm;
 	directx_priv *priv = GGIDIRECTX_PRIV(vis);
 
+	priv->nThreadID = GetCurrentThreadId();
+
 	/* create the window */
 	if (!DDCreateWindow(vis)) {
 		SetEvent(priv->hInit);
@@ -881,7 +787,7 @@ DDEventLoop(void *lpParm)
 	while (GetMessage(&msg, NULL, 0, 0)) {
 		if (msg.hwnd == NULL && msg.message == WM_DDEND) {
 			/* Use PostThreadMessage to get here */
-			GGIDPRINT("display-directx: Ending session, "
+			DPRINT("Ending session, "
 				  "destroying window.\n");
 			DestroyWindow(priv->hWnd);
 			break;
@@ -890,17 +796,18 @@ DDEventLoop(void *lpParm)
 			directx_fullscreen *dxfull =
 				(directx_fullscreen *)msg.lParam;
 			if (!dxfull) {
-				fprintf(stderr, "directx: Aieee! "
+				fprintf(stderr, "Aieee! "
 					"No lParam for WM_DDFULLSCREEN\n");
 				exit(1);
 			}
-			GGIDPRINT_MODE("Set coop level\n");
+			DPRINT_MODE("Set coop level\n");
 			dxfull->hr = IDirectDraw2_SetCooperativeLevel(
 				dxfull->priv->lpddext, dxfull->priv->hWnd,
 				DDSCL_EXCLUSIVE | DDSCL_FULLSCREEN);
 			if (FAILED(dxfull->hr))
-				GGIDPRINT_MODE("failed %x\n", dxfull->hr);
-			GGIDPRINT_MODE("directx: Set fullscreen mode "
+				DPRINT_MODE("SetCooperativeLevel failed %x\n",
+					dxfull->hr);
+			DPRINT_MODE("Set fullscreen mode "
 				"(%i,%i) size %d\n",
 				dxfull->mode->visible.x,
 				dxfull->mode->visible.y,
@@ -911,7 +818,7 @@ DDEventLoop(void *lpParm)
 				dxfull->mode->visible.y,
 				GT_SIZE(dxfull->mode->graphtype), 0, 0);
 			if (FAILED(dxfull->hr))
-				GGIDPRINT_MODE("directx: failed %x\n",
+				DPRINT_MODE("SetDisplayMode failed %x\n",
 					dxfull->hr);
 			SetEvent(dxfull->event);
 			continue;
@@ -920,7 +827,7 @@ DDEventLoop(void *lpParm)
 		TranslateMessage(&msg);
 		DispatchMessage(&msg);
 	}
-	GGIDPRINT("display-directx: Helper thread terminating\n");
+	DPRINT("Helper thread terminating\n");
 
 #ifndef __CYGWIN__
 	_endthreadex(msg.wParam);
@@ -934,9 +841,13 @@ DDCreateThread(ggi_visual *vis)
 	directx_priv *priv = GGIDIRECTX_PRIV(vis);
 	priv->hInit = CreateEvent(NULL, FALSE, FALSE, NULL);
 #ifdef __CYGWIN__
+	if (pthread_create((pthread_t *)&priv->hThread, NULL, DDEventLoop, vis))
+		priv->nThreadID = 0;
+	/*
 	priv->hThread = CreateThread(NULL, 0,
 				     (LPTHREAD_START_ROUTINE) DDEventLoop,
 				     vis, 0, &priv->nThreadID);
+	*/
 #else
 	priv->hThread =
 	    (HANDLE) _beginthreadex(NULL, 0, DDEventLoop, vis, 0,
@@ -963,7 +874,7 @@ int DDChangePalette(ggi_visual *vis)
 	int x;
 	static PALETTEENTRY pal[256];
 
-	LIBGGI_ASSERT(priv->lpddp, "No palette!\n");
+	LIB_ASSERT(priv->lpddp, "No palette!\n");
 
 	if (start >= stop)
 		return 0;
@@ -1151,14 +1062,14 @@ DDChangeWindow(directx_priv *priv, DWORD width, DWORD height)
 	RECT r1, r2;
 	if (priv->hParent)
 		return;
-	EnterCriticalSection(&priv->sizingcs);
+	GGI_directx_Lock(priv->sizingcs);
 	priv->xmin = width;
 	priv->ymin = height;
 	priv->xmax = width;
 	priv->ymax = height;
 	priv->xstep = 1;
 	priv->ystep = 1;
-	LeaveCriticalSection(&priv->sizingcs);
+	GGI_directx_Unlock(priv->sizingcs);
 	GetWindowRect(priv->hWnd, &r1);
 	r2 = r1;
 	AdjustWindowRectEx(&r2, ws_style, FALSE, 0);
