@@ -1,4 +1,4 @@
-/* $Id: mode.c,v 1.9 2004/10/14 11:01:33 cegger Exp $
+/* $Id: mode.c,v 1.19 2005/08/15 18:50:58 cegger Exp $
 ******************************************************************************
 
    LibGGI Mode management.
@@ -27,7 +27,9 @@
 */
 
 #include "config.h"
+#include <ggi/internal/gg_replace.h>
 #include <ggi/internal/internal.h>
+#include <ggi/internal/ggi_debug.h>
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -79,27 +81,27 @@ int ggiSetMode(ggi_visual *vis,ggi_mode *tm)
 	int retval;
 	ggi_mode oldmode;
 
-	LIBGGI_APPASSERT(vis != NULL, "ggiSetMode: vis == NULL");
-	LIBGGI_APPASSERT(tm != NULL,  "ggiSetMode: tm == NULL");
+	APP_ASSERT(vis != NULL, "ggiSetMode: vis == NULL");
+	APP_ASSERT(tm != NULL,  "ggiSetMode: tm == NULL");
 
 #ifdef DEBUG
-	if ((_ggiDebugState & GGIDEBUG_CORE)
-	    || (_ggiDebugState & GGIDEBUG_MODE)) {
-		fprintf(stderr, "LibGGI: ggiSetMode(%p, ", vis);
+	if ((_ggiDebug & DEBUG_CORE)
+	    || (_ggiDebug & DEBUG_MODE)) {
+		fprintf(stderr, "LibGGI: ggiSetMode(%p, ", (void *)vis);
 		ggiFPrintMode(stderr, tm);
 		fprintf(stderr, ") called\n");
 	}
 #endif
 	ggLock(vis->mutex);
 
-	GGIDPRINT_MODE("ggiSetMode: trying (vis %dx%d virt %dx%d)\n",
+	DPRINT_MODE("ggiSetMode: trying (vis %dx%d virt %dx%d)\n",
 		    tm->visible.x,tm->visible.y,tm->virt.x,tm->virt.y);
 	_ggiCheck4Defaults(tm);
                
 	memcpy(&oldmode, tm, sizeof(ggi_mode));
-	GGIDPRINT_MODE("ggiSetMode: trying2 (vis %dx%d virt %dx%d)\n",
+	DPRINT_MODE("ggiSetMode: trying2 (vis %dx%d virt %dx%d)\n",
 		tm->visible.x,tm->visible.y,tm->virt.x,tm->virt.y);
-	GGIDPRINT_MODE("ggiSetMode: calling %p\n",vis->opdisplay->setmode);
+	DPRINT_MODE("ggiSetMode: calling %p\n",vis->opdisplay->setmode);
 
 	retval=vis->opdisplay->setmode(vis,tm);
 
@@ -111,14 +113,14 @@ int ggiSetMode(ggi_visual *vis,ggi_mode *tm)
 		int i;
 		ggi_color col;
 
-		GGIDPRINT_CORE("ggiSetMode: set to frame 0, origin = {0,0}\n");
+		DPRINT_CORE("ggiSetMode: set to frame 0, origin = {0,0}\n");
 		ggiSetDisplayFrame(vis, 0);
 		ggiSetReadFrame(vis, 0);
 		ggiSetOrigin(vis,0,0);
-		GGIDPRINT_CORE("ggiSetMode: set GC\n");
+		DPRINT_CORE("ggiSetMode: set GC\n");
 		/* Set clipping rectangle to the full (virtual) screen */
 		ggiSetGCClipping(vis,0,0,tm->virt.x,tm->virt.y);
-		GGIDPRINT_CORE("ggiSetMode: success (vis %dx%d virt %dx%d)\n",
+		DPRINT_CORE("ggiSetMode: success (vis %dx%d virt %dx%d)\n",
 			    tm->visible.x,tm->visible.y,tm->virt.x,tm->virt.y);
 		/* Set foreground and background to black */
 		col.r = 0;
@@ -128,22 +130,22 @@ int ggiSetMode(ggi_visual *vis,ggi_mode *tm)
 		ggiSetGCBackground(vis, ggiMapColor(vis, &col));
 		/* Clear frames to black */
 		for (i = 0; i < tm->frames; i++) {
-			GGIDPRINT_CORE("ggiSetMode: SetWriteFrame %d\n", i);
+			DPRINT_CORE("ggiSetMode: SetWriteFrame %d\n", i);
 			ggiSetWriteFrame(vis, i);
 #ifdef DEBUG
 			if (vis->w_frame) {
-				GGIDPRINT_CORE("ggiSetMode: frame address: "
+				DPRINT_CORE("ggiSetMode: frame address: "
 					       "%p\n", vis->w_frame->write);
 			}
 #endif
-			GGIDPRINT_CORE("ggiSetMode: FillScreen %d\n", i);
+			DPRINT_CORE("ggiSetMode: FillScreen %d\n", i);
 			ggiFillscreen(vis);
 		}
 		ggiSetWriteFrame(vis, 0);
 		ggiFlush(vis);
 	}
 
-	GGIDPRINT_CORE("ggiSetMode: done!\n");
+	DPRINT_CORE("ggiSetMode: done!\n");
 	ggUnlock(vis->mutex);
 
 	return retval;
@@ -155,10 +157,10 @@ int ggiSetMode(ggi_visual *vis,ggi_mode *tm)
 
 int ggiCheckMode(ggi_visual *vis,ggi_mode *tm)
 {
-	LIBGGI_APPASSERT(vis != NULL, "ggiCheckMode: vis == NULL");
-	LIBGGI_APPASSERT(tm != NULL,  "ggiCheckMode: tm == NULL");
+	APP_ASSERT(vis != NULL, "ggiCheckMode: vis == NULL");
+	APP_ASSERT(tm != NULL,  "ggiCheckMode: tm == NULL");
 
-	GGIDPRINT_CORE("ggiCheckMode(%p, %p) called\n", vis, tm);
+	DPRINT_CORE("ggiCheckMode(%p, %p) called\n", vis, tm);
 
 	_ggiCheck4Defaults(tm);
 	return vis->opdisplay->checkmode(vis,tm);
@@ -170,10 +172,10 @@ int ggiCheckMode(ggi_visual *vis,ggi_mode *tm)
 
 int ggiGetMode(ggi_visual *vis,ggi_mode *tm)
 {
-	LIBGGI_APPASSERT(vis != NULL, "ggiGetMode: vis != NULL");
-	LIBGGI_APPASSERT(tm != NULL,  "ggiGetMode: tm != NULL");
+	APP_ASSERT(vis != NULL, "ggiGetMode: vis != NULL");
+	APP_ASSERT(tm != NULL,  "ggiGetMode: tm != NULL");
 
-	GGIDPRINT_CORE("ggiGetMode(%p, %p) called\n", vis, tm);
+	DPRINT_CORE("ggiGetMode(%p, %p) called\n", vis, tm);
 
 	return vis->opdisplay->getmode(vis,tm);
 }
@@ -188,7 +190,7 @@ int ggiSetTextMode(ggi_visual *vis,int cols,int rows,
 {
 	ggi_mode mode;
 	
-	GGIDPRINT_CORE("ggiSetTextMode(%p, %d, %d, %d, %d, %d, %d, 0x%x) called\n",
+	DPRINT_CORE("ggiSetTextMode(%p, %d, %d, %d, %d, %d, %d, 0x%x) called\n",
 		    cols, rows, vcols, vrows, fontsizex, fontsizey, type);
 	
 	mode.frames    = GGI_AUTO;
@@ -216,7 +218,7 @@ int ggiCheckTextMode(ggi_visual *vis,int cols,int rows,
 	int rc;
 	ggi_mode mode;
         
-	GGIDPRINT_CORE("ggiCheckTextMode(%p, %d, %d, %d, %d, %d, %d, 0x%x, %p) called\n",
+	DPRINT_CORE("ggiCheckTextMode(%p, %d, %d, %d, %d, %d, %d, 0x%x, %p) called\n",
 		    vis, cols, rows, vcols, vrows, fontsizex, fontsizey,
 		    type, md);
 	
@@ -242,7 +244,7 @@ int ggiSetGraphMode(ggi_visual *vis,int xsize,int ysize,
 		    int xvirtual,int yvirtual,ggi_graphtype type)
 {
 	ggi_mode mode;
-	GGIDPRINT_CORE("ggiSetGraphMode(%p, %d, %d, %d, %d, 0x%x) called\n",
+	DPRINT_CORE("ggiSetGraphMode(%p, %d, %d, %d, %d, 0x%x) called\n",
 		    vis, xsize, ysize, xvirtual, yvirtual, type);
 	
 	mode.frames    = GGI_AUTO;
@@ -267,7 +269,7 @@ int ggiCheckGraphMode(ggi_visual *visual,int xsize,int ysize,
 	int rc;
 	ggi_mode mode;
 	
-	GGIDPRINT_CORE("ggiCheckGraphMode(%p, %d, %d, %d, %d, 0x%x, %p) called\n",
+	DPRINT_CORE("ggiCheckGraphMode(%p, %d, %d, %d, %d, 0x%x, %p) called\n",
 		    visual, xsize, ysize, xvirtual, yvirtual, type, md);
 	
 	mode.frames    = GGI_AUTO;
@@ -292,7 +294,7 @@ int ggiSetSimpleMode(ggi_visual *vis, int xsize, int ysize, int frames,
 		     ggi_graphtype type)
 {
 	ggi_mode mode;
-	GGIDPRINT_CORE("ggiSetSimpleMode(%p, %d, %d, %d, 0x%x) called\n",
+	DPRINT_CORE("ggiSetSimpleMode(%p, %d, %d, %d, 0x%x) called\n",
 		    vis, xsize, ysize, frames, type);
 	
 	mode.frames    = frames;
@@ -315,7 +317,7 @@ int ggiCheckSimpleMode(ggi_visual *visual, int xsize, int ysize, int frames,
 	int rc;
 	ggi_mode mode;
 	
-	GGIDPRINT_CORE("ggiCheckSimpleMode(%p, %d, %d, %d, 0x%x, %p) called\n",
+	DPRINT_CORE("ggiCheckSimpleMode(%p, %d, %d, %d, 0x%x, %p) called\n",
 		    visual, xsize, ysize, frames, type, md);
 	
 	mode.frames    = frames;
@@ -335,7 +337,7 @@ int ggiCheckSimpleMode(ggi_visual *visual, int xsize, int ysize, int frames,
 /* print mode      */
 /*******************/
 
-int ggiSPrintMode(char *s, ggi_mode *m)
+int ggiSPrintMode(char *s, const ggi_mode *m)
 {
 	int n;
 	
@@ -381,7 +383,7 @@ int ggiSPrintMode(char *s, ggi_mode *m)
 	return 0;
 }
 
-int ggiFPrintMode(FILE *s, ggi_mode *m)
+int ggiFPrintMode(FILE *s, const ggi_mode *m)
 {
 	char buf[256];
 
@@ -441,15 +443,15 @@ int ggiFPrintMode(FILE *s, ggi_mode *m)
  * for failure.
  */
 
-#define SKIPSPACE   while ((*s) && (isspace((int)*s) || (*s == '.'))) s++
+#define SKIPSPACE   while ((*s) && (isspace((uint8_t)*s) || (*s == '.'))) s++
  
 /* scan the integer from the string pointer s */
 
 #define SCANINT(x,def)                             \
 	SKIPSPACE;  x = def;                       \
-	if (isdigit((int) *s)) {                   \
+	if (isdigit((uint8_t) *s)) {                 \
 		x = *s++ - '0';                    \
-		while (isdigit((int) *s)) {        \
+		while (isdigit((uint8_t) *s)) {      \
 			x = x*10 + (*s++ - '0');   \
 		}                                  \
 	}                                          \
@@ -465,7 +467,7 @@ int ggiParseMode(const char * s, ggi_mode * m)
 
 	if (s == NULL) s = "";
 
-	GGIDPRINT_CORE("ggiParseMode(\"%s\", %p) called\n", s, m);
+	DPRINT_CORE("ggiParseMode(\"%s\", %p) called\n", s, m);
 
 	*m = _ggiDefaultMode;
 
@@ -473,62 +475,65 @@ int ggiParseMode(const char * s, ggi_mode * m)
 
 		SKIPSPACE;
 
-		if ((tolower((int)*s)=='s') || isdigit((int)*s)) {	/* visible */
-			if (! isdigit((int)*s)) s++;
+		/* visible */
+		if ((tolower((uint8_t)*s)=='s') || isdigit((uint8_t)*s)) {
+			if (! isdigit((uint8_t)*s)) s++;
 			SCANINT(m->visible.x, GGI_AUTO);
-			if (tolower((int) *s) == 'x') {
+			if (tolower((uint8_t) *s) == 'x') {
 				s++; SCANINT(m->visible.y, GGI_AUTO);
 			}
-			if (tolower((int) *s) == 'x') {
+			if (tolower((uint8_t) *s) == 'x') {
 				s++; SCANINT(depth, GT_AUTO);
 				GT_SETDEPTH(m->graphtype, depth);
 			}
 			continue;
 		}
 		
-		if ((*s=='#') || (tolower((int) *s)=='v')) {	/* virtual */
+		/* virtual */
+		if ((*s=='#') || (tolower((uint8_t) *s)=='v')) {
 			s++; SCANINT(m->virt.x, GGI_AUTO);
-			if (tolower((int) *s) == 'x') {
+			if (tolower((uint8_t) *s) == 'x') {
 				s++; SCANINT(m->virt.y, GGI_AUTO);
 			}
 			continue;
 		}
 
-		if (tolower((int) *s)=='f') {	/* frames */
+		/* frames */
+		if (tolower((uint8_t) *s)=='f') {
 			s++; SCANINT(m->frames, GGI_AUTO);
 			continue;
 		}
 
-		if (tolower((int) *s)=='d') {  /* dpp */
+		if (tolower((uint8_t) *s)=='d') {  /* dpp */
 			s++; SCANINT(m->dpp.x, GGI_AUTO);
-			if (tolower((int) *s) == 'x') {
+			if (tolower((uint8_t) *s) == 'x') {
 				s++; SCANINT(m->dpp.y, GGI_AUTO);
 			}
 			continue;
 		}
 
-		if (tolower((int) *s)=='p') {  /* palette */
+		if (tolower((uint8_t) *s)=='p') {  /* palette */
 			s++; SCANINT(depth, GT_AUTO);
 			GT_SETSCHEME(m->graphtype, GT_PALETTE);
 			GT_SETDEPTH(m->graphtype, depth);
 			continue;
 		}
 
-		if (tolower((int) *s)=='c') {  /* truecolor */
+		if (tolower((uint8_t) *s)=='c') {  /* truecolor */
 			s++; SCANINT(depth, GT_AUTO);
 			GT_SETSCHEME(m->graphtype, GT_TRUECOLOR);
 			GT_SETDEPTH(m->graphtype, depth);
 			continue;
 		}
 
-		if (tolower((int) *s)=='k') {  /* greyscale */
+		if (tolower((uint8_t) *s)=='k') {  /* greyscale */
 			s++; SCANINT(depth, GT_AUTO);
 			GT_SETSCHEME(m->graphtype, GT_GREYSCALE);
 			GT_SETDEPTH(m->graphtype, depth);
 			continue;
 		}
 
-		if (tolower((int) *s)=='t') {  /* text */
+		if (tolower((uint8_t) *s)=='t') {  /* text */
 			s++; SCANINT(depth, GT_AUTO);
 			GT_SETSCHEME(m->graphtype, GT_TEXT);
 			GT_SETDEPTH(m->graphtype, depth);
@@ -552,19 +557,19 @@ int ggiParseMode(const char * s, ggi_mode * m)
 		CHECKGTMODE("GT_TEXT16]", 10, GT_TEXT16);
 		CHECKGTMODE("GT_TEXT32]", 10, GT_TEXT32);
 	
-		if (tolower((int) *s) == 't') {  /* text */
+		if (tolower((uint8_t) *s) == 't') {  /* text */
 			GT_SETSCHEME(m->graphtype, GT_TEXT);
 			s++;
 		} else
-		if (tolower((int) *s) == 'p') {  /* palette */
+		if (tolower((uint8_t) *s) == 'p') {  /* palette */
 			GT_SETSCHEME(m->graphtype, GT_PALETTE);
 			s++;
 		} else
-		if (tolower((int) *s) == 'c') {  /* truecolor */
+		if (tolower((uint8_t) *s) == 'c') {  /* truecolor */
 			GT_SETSCHEME(m->graphtype, GT_TRUECOLOR);
 			s++;
 		} else
-		if (tolower((int) *s) == 'k') {  /* greyscale */
+		if (tolower((uint8_t) *s) == 'k') {  /* greyscale */
 			GT_SETSCHEME(m->graphtype, GT_GREYSCALE);
 			s++;
 		}
@@ -609,15 +614,15 @@ int ggiParseMode(const char * s, ggi_mode * m)
 	int negative=0;  /* negative flag for positions */
 	int xposition=0;
 	int yposition=0;
-	GGIDPRINT_CORE("ggiParseMode(%p, %p) called\n", s, m);
+	DPRINT_CORE("ggiParseMode(%p, %p) called\n", s, m);
 	*m = _ggiDefaultMode;
-#define SKIPSPACE   while ( (*s!='\000') && (isspace((int)*s)) ) s++;
+#define SKIPSPACE   while ( (*s!='\000') && (isspace((uint8_t)*s)) ) s++;
 /* scan the integer from the string pointer s */
 #define SCANINT(x)  SKIPSPACE;                 \
-		    if (isdigit((int)*s)){          \
+		    if (isdigit((uint8_t)*s)){        \
 		       x=*s-'0';               \
 	               s++;                    \
-		       while (isdigit((int)*s)){    \
+		       while (isdigit((uint8_t)*s)){  \
 			  x = x*10+ ((int)*s) -'0'; \
 			  s++;                 \
 		       }                       \
@@ -625,27 +630,27 @@ int ggiParseMode(const char * s, ggi_mode * m)
 		    SKIPSPACE
 	/* first number is visible-x: */
 	SCANINT(m->visible.x);
-	if (tolower((int)*s) == 'x') { /* now for the y */
+	if (tolower((uint8_t)*s) == 'x') { /* now for the y */
 		s++;
 		SCANINT(m->visible.y);
 	}
 	if (*s == '#'){ /* virtual starts here */
 		s++;
 		SCANINT(m->virt.x);
-		if (tolower((int)*s) == 'x') { /* now for the y */
+		if (tolower((uint8_t)*s) == 'x') { /* now for the y */
 			s++;
 			SCANINT(m->virt.y);
 		}
 	}
-	if (tolower((int)*s) == 'd') { /* dpp starts here */
+	if (tolower((uint8_t)*s) == 'd') { /* dpp starts here */
 		s++;
 		SCANINT(m->dpp.x);
-		if (tolower((int)*s) == 'x') { /* now for the y */
+		if (tolower((uint8_t)*s) == 'x') { /* now for the y */
 			s++;
 			SCANINT(m->dpp.y);
 		}
 	}
-	if (tolower((int)*s) == 'f') { /* frames starts here */
+	if (tolower((uint8_t)*s) == 'f') { /* frames starts here */
 		s++;
 		SCANINT(m->frames);
 	}
@@ -666,19 +671,19 @@ int ggiParseMode(const char * s, ggi_mode * m)
 		CHECKGTMODE("GT_TEXT32]", 10, GT_TEXT32) else
 		{
 			/* scheme */
-			if (tolower((int)*s) == 't') {  /* text mode */
+			if (tolower((uint8_t)*s) == 't') {  /* text mode */
 				GT_SETSCHEME(m->graphtype, GT_TEXT);
 				s++;
 			} else
-			if (tolower((int)*s) == 'p') {  /* palette mode */
+			if (tolower((uint8_t)*s) == 'p') {  /* palette mode */
 				GT_SETSCHEME(m->graphtype, GT_PALETTE);
 				s++;
 			} else
-			if (tolower((int)*s) == 'c') {  /* truecolor mode */
+			if (tolower((uint8_t)*s) == 'c') {  /* truecolor mode */
 				GT_SETSCHEME(m->graphtype, GT_TRUECOLOR);
 				s++;
 			} else
-			if (tolower((int)*s) == 'k') {  /* greyscale mode */
+			if (tolower((uint8_t)*s) == 'k') {  /* greyscale mode */
 				GT_SETSCHEME(m->graphtype, GT_GREYSCALE);
 				s++;
 			}
@@ -826,12 +831,12 @@ int _ggi_physz_figure_visible(ggi_mode *mode, int def_x, int def_y,
 	ggi_coord size, res;
 	ggi_mode tmp;
 
-	GGIDPRINT_MODE("_ggi_physz_figure_visible(%p) called\n",
+	DPRINT_MODE("_ggi_physz_figure_visible(%p) called\n",
 			mode);
 
-	LIBGGI_ASSERT(mode != NULL, "Invalid mode");
-	LIBGGI_ASSERT(screen_size != NULL, "Invalid screen size");
-	LIBGGI_ASSERT(screen_res != NULL, "Invalid screen resolution");
+	LIB_ASSERT(mode != NULL, "Invalid mode");
+	LIB_ASSERT(screen_size != NULL, "Invalid screen size");
+	LIB_ASSERT(screen_res != NULL, "Invalid screen resolution");
 
 	memset(&tmp, GGI_AUTO, sizeof(tmp));
 
@@ -884,11 +889,11 @@ int _ggi_physz_figure_visible(ggi_mode *mode, int def_x, int def_y,
 	}
 
 
-	GGIDPRINT_MODE("_ggi_physz_figure_visible: mode dpp (%i,%i), size (%i,%i)\n",
+	DPRINT_MODE("_ggi_physz_figure_visible: mode dpp (%i,%i), size (%i,%i)\n",
 			mode->dpp.x, mode->dpp.y,
 			mode->size.x, mode->size.y);
 
-	GGIDPRINT_MODE("_ggi_physz_figure_visible: visible (%i,%i), virt (%i,%i)\n",
+	DPRINT_MODE("_ggi_physz_figure_visible: visible (%i,%i), virt (%i,%i)\n",
 			tmp.visible.x, tmp.visible.y, mode->virt.x, mode->virt.y);
 
 	if ((mode->virt.x != GGI_AUTO)
@@ -909,7 +914,7 @@ int _ggi_physz_figure_visible(ggi_mode *mode, int def_x, int def_y,
 	if ((mode->visible.x != GGI_AUTO && mode->visible.x != tmp.visible.x)
 	  || (mode->visible.y != GGI_AUTO && mode->visible.y != tmp.visible.y))
 	{
-		GGIDPRINT_MODE("_ggi_physz_figure_visible: "
+		DPRINT_MODE("_ggi_physz_figure_visible: "
 			"physical size (%i,%i) doesn't match (%i,%i)\n",
 			mode->size.x, mode->size.y, mode->visible.x, mode->visible.y);
 
@@ -920,9 +925,9 @@ int _ggi_physz_figure_visible(ggi_mode *mode, int def_x, int def_y,
 	mode->visible = tmp.visible;
 	mode->virt = tmp.virt;
 
-	GGIDPRINT_MODE("_ggi_physz_figure_visible: visible (%i,%i), virt (%i,%i)\n",
+	DPRINT_MODE("_ggi_physz_figure_visible: visible (%i,%i), virt (%i,%i)\n",
 			mode->visible.x, mode->visible.y, mode->virt.x, mode->virt.y);
-	GGIDPRINT_MODE("_ggi_physz_figure_visible: leaving\n");
+	DPRINT_MODE("_ggi_physz_figure_visible: leaving\n");
 
 	return GGI_OK;
 }
@@ -965,6 +970,20 @@ int _ggi_physz_figure_size(ggi_mode *mode, int physzflag, const ggi_coord *op_sz
 		/* find absolute size in mm */
 		xsize = mode->visible.x * mode->dpp.x * 254 / xsize / 10;
 		ysize = mode->visible.y * mode->dpp.y * 254 / ysize / 10;
+
+	} else if (physzflag & GGI_PHYSZ_MM) {
+		xsize = (physzflag & GGI_PHYSZ_OVERRIDE) ? op_sz->x : dpix;
+		ysize = (physzflag & GGI_PHYSZ_OVERRIDE) ? op_sz->y : dpiy;
+		if (xsize <= 0 || ysize <= 0) {
+			xsize = op_sz->x;
+			ysize = op_sz->y;
+		}
+		if (xsize <= 0 || ysize <= 0) goto nosize;
+		/* Now xsize and ysize are in mm, but scale them
+		 * to mode->visible */
+		xsize = xsize * mode->visible.x / dsx;
+		ysize = ysize * mode->visible.y / dsy;
+
 	} else {
 		if (physzflag & GGI_PHYSZ_OVERRIDE) {
 			xsize = op_sz->x;
@@ -986,7 +1005,7 @@ int _ggi_physz_figure_size(ggi_mode *mode, int physzflag, const ggi_coord *op_sz
 	if ((mode->size.x != xsize && mode->size.x != GGI_AUTO) ||
 	    (mode->size.y != ysize && mode->size.y != GGI_AUTO))
 	{
-		GGIDPRINT_MODE("_ggi_physz_figure_size: "
+		DPRINT_MODE("_ggi_physz_figure_size: "
 			"physical size (%i,%i) doesn't match (%i,%i)\n",
 			xsize, ysize, mode->size.x, mode->size.y);
 		err = GGI_ENOMATCH;
