@@ -1,4 +1,4 @@
-/* $Id: consistency.c,v 1.6 2004/09/08 19:26:22 cegger Exp $
+/* $Id: consistency.c,v 1.8 2005/07/30 08:43:01 soyt Exp $
 ******************************************************************************
 
    This is a consistency-test application.
@@ -15,6 +15,7 @@
 ******************************************************************************
 */
 
+#include "config.h"
 #include <ggi/ggi.h>
 
 #include <stdio.h>
@@ -529,7 +530,8 @@ static void CopyBox(void)
  * checking and contains which checks to run.
  */
 static struct test
-{	char *name;
+{
+	const char *name;
 	void (*func)(void);
 	int active;
 } tests[]=
